@@ -44,8 +44,12 @@ pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
 pub use self::error_detail::ErrorDetail;
+pub mod event_request;
+pub use self::event_request::EventRequest;
 pub mod event_source;
 pub use self::event_source::EventSource;
+pub mod event_type;
+pub use self::event_type::EventType;
 pub mod experiment;
 pub use self::experiment::Experiment;
 pub mod experiment_device_config;
@@ -218,8 +222,6 @@ pub mod patched_user_request;
 pub use self::patched_user_request::PatchedUserRequest;
 pub mod polymorphic_event;
 pub use self::polymorphic_event::PolymorphicEvent;
-pub mod polymorphic_event_request;
-pub use self::polymorphic_event_request::PolymorphicEventRequest;
 pub mod print_job_event;
 pub use self::print_job_event::PrintJobEvent;
 pub mod print_job_event_request;
